##  Adding SAP LeanIX Items to Confluence
Insert one or more macros into your Confluence pages to make your SAP LeanIX reports, diagrams, and fact sheets available in Confluence. The process will differ depending on the type of content you want to include.
